@@ -1,12 +1,14 @@
 test_that("benchmark", {
   skip_on_cran()
 
-  cdm <- duckdb::dbConnect(duckdb::duckdb(), CDMConnector::eunomiaDir()) |>
-    CDMConnector::cdmFromCon(cdmSchema = "main", writeSchema = "main") |>
-    CDMConnector::generateConceptCohortSet(
-      conceptSet = list(sinusitis = 40481087, pharyngitis = 4112343),
-      name = "my_cohort"
-    )
+  cdm <- omock::mockCdmFromDataset(datasetName = "GiBleed", source = "local") |>
+    copyCdm()
+
+  cdm <- CDMConnector::generateConceptCohortSet(
+    cdm = cdm,
+    conceptSet = list(sinusitis = 40481087, pharyngitis = 4112343),
+    name = "my_cohort"
+  )
 
   expect_no_error(res <- benchmarkCohortCharacteristics(cdm$my_cohort))
   expect_true(inherits(res, "summarised_result"))
@@ -16,4 +18,5 @@ test_that("benchmark", {
   expect_true(inherits(res, "summarised_result"))
   expect_true(nrow(res) == 0)
 
+  dropCreatedTables(cdm = cdm)
 })
